### $.contentApi.endpoint_$endpoint
Enable and change behavior of ContentApi endpoints. The minimal requirement to enable an endpoint is to
define an `{apiVersion}` for it. If that is not defined, the DmgzContentApi will throw an exception, causing
a fallback to SearchApi.

This config works with a matching principle which means that, for each endpoint, it defines a list of
candidates. The first eligible candidate will be chosen based on the `matchingVariables` object. If all of
the variables defined there are also present in the actual request being made.
When a candidate matches, all the values in the `addVariables` object will be added to the variables map
that is passed to the SDK, which will then replace any placeholder occurrences with the actual value.
Some variables that are typically added to each request are:
- `{region}`
- `{apiVersion}`
- `{appLanguage}`
- `{kidsModeEnabled}`

Additionally there is a possibility to override the actual endpoint that is being hit by specifying
`{endpointOverride}`. So if the app requests content from the `getStandardCollection` endpoint you can
change that either for all invocations, or by using `matchingVariables` only for a specific `{slug}`.

Here is an example how to enable specific endpoint, we have to define endpoint and apiVersion:
{
  "contentApi": {
    "endpoint_getStandardCollection": [
      {
        "addVariables": {
          "{apiVersion}": "3.2"
        },
        "matchingVariables": {
          "{slug}": "explore"
        }
      }
    ]
  }
}

If we want to change apiVersion or disable rest endpoint for specific slug we can do it as follows:
{
  "contentApi": {
    "endpoint_getStandardCollection": [
      {
        "matchingVariables": {
          "{slug}": "watchlist"
        },
        "addVariables": {} // if we don't define apiVersion request is disabled
      },
      {
        "matchingVariables": {
          "{slug}": "originals"
        },
        "addVariables": {}
         "removeKeys" : ["{apiVersion}"] // alternate way to disable request
      },
      {
        "matchingVariables": {
          "{slug}": "watchlist"
        },
        "addVariables": {
        }
      },
      {
        "matchingVariables": {
          "{slug}": "explore"
        },
        "addVariables": {
          "{apiVersion}": "4.0" // overriden apiVersion for slug "explore"
        }
      },{
        "matchingVariables": {}, // default values for getDmcCollection
        "addVariables": {
          "{apiVersion}": "3.0"
        }
      }
    ]
  }
}

We can also override other parameters for specific endpoint.
Here is an example how to override pageSize for getCuratedSet
{
  "contentApi": {
    "endpoint_getSet": [
      {
        "addVariables": {
          "{apiVersion}": "3.2",
          "{pageSize}": "30"
        }
      }
    ]
  }
}
