### $.exploreApi.endpoint_$endpoint
Enable and change behavior of ExploreApi endpoints. The minimal requirement to enable an endpoint is to
define an `{version}` for it. If that is not defined, the DmgzExploreApi will throw an exception.

This config works with a matching principle which means that, for each endpoint, it defines a list of
candidates. The first eligible candidate will be chosen based on the `matchingVariables` object. If all of
the variables defined there are also present in the actual request being made.
When a candidate matches, all the values in the `addVariables` object will be added to the variables map
that is passed to the SDK, which will then replace any placeholder occurrences with the actual value.

Additionally there is a possibility to override the actual endpoint that is being hit by specifying
`{endpointOverride}`. So if the app requests content from the `getPage` endpoint you can
change that either for all invocations, or by using `matchingVariables` only for a specific `{pageId}`.

Here is an example how to enable specific endpoint, we have to define endpoint and version:
{
  "exploreApi": {
    "endpoint_getPage": [
      {
        "addVariables": {
          "{version}": "3.2"
        },
        "matchingVariables": {
          "{pageId}": "RequestedPageId"
        }
      }
    ]
  }
}

If we want to change version or disable rest endpoint for specific pageId we can do it as follows:
{
  "exploreApi": {
    "endpoint_getPage": [
      {
        "matchingVariables": {
          "{pageId}": "RequestedPageId"
        },
        "addVariables": {} // if we don't define version request is disabled
      },
      {
        "matchingVariables": {
          "{pageId}": "RequestedPageId"
        },
        "addVariables": {}
         "removeKeys" : ["{version}"] // alternate way to disable request
      },
      {
        "matchingVariables": {
          "{pageId}": "RequestedPageId"
        },
        "addVariables": {
        }
      },
      {
        "matchingVariables": {
          "{pageId}": "RequestedPageId"
        },
        "addVariables": {
          "{version}": "4.0" // overriden version for pageId "RequestedPageId"
        }
      },{
        "matchingVariables": {}, // default values for getPage
        "addVariables": {
          "{version}": "3.0"
        }
      }
    ]
  }
}

We can also override other parameters for specific endpoint.
Here is an example how to override refIdType for all getSet requests.
{
  "exploreApi": {
    "endpoint_getSet": [
      {
        "addVariables": {
          "{version}": "3.2",
          "{refIdType}": "deeplinkId"
        }
      }
    ]
  }
}

Added in `2.23`
